---
title: "Markdown Syntax"
prio: 4
---

:::info
Die Markdown Syntax baut auf der [Markdown Syntax von Pandoc](https://pandoc.org/MANUAL.html#pandocs-markdown) auf. Es sind einige Extensions aktiviert, um die Syntax möglichst ähnlich zur [Hedgedoc Markdown Syntax](https://pad.gwdg.de/features) zu machen.

Die vollständige Markdown Syntax die verwendet werden kann ist also sehr umfangreich. Dieses Dokument *sollte* alle Features und Schreibweisen aufzeigen.
:::

Markdowncodebeispiele zusammen mit den entsprechenden Ergebnissen die generiert wurden sehen in diesem Dokument wie folgt aus:
```markdown
Ich bin ein *Markdown* Beispiel.
```

:::success
Ich bin ein *Markdown* Beispiel.
:::

## Inhaltsverzeichnis

Ein Paragraph mit einzigem Inhalt `[TOC]` generiert ein Inhaltsverzeichnis.

```markdown

[TOC]

```

:::success

[TOC]

:::


## Paragraphen

Ein Paragraph besteht aus einer oder mehr Zeilen an Text gefolgt von einer oder mehreren Leerzeilen.
Ein Zeilenumbruch in einem Paragraphen wird, wie in Hedgedoc auch, direkt auf der Webseite als Zeilenumbruch übernommen.

```markdown
Dies ist der erste Paragraph.

Dies ist der zweite Paragraph und dieser Paragraph
beinhaltet sogar einen Zeilenumbruch.
```

:::success
Dies ist der erste Paragraph.

Dies ist der zweite Paragraph und dieser Paragraph
beinhaltet sogar einen Zeilenumbruch.
:::

## Überschriften

Überschriften werden genutzt um ein Dokument zu strukturieren.

Es gibt zwei Arten Überschriften zu schreiben: [Setext](#setext) und [ATX](#atx).
In Überschriften kann [Inlinemarkup](#inlinemarkup) verwendet werden.
Eine Leerzeile vor oder nach einer Überschrift ist nicht notwendig.

### Nutzungsinformationen

- Jede Seite wird automatisch mit einer Level 1 Überschrift aus dem Titel generiert.
  Entsprechend sollten die meisten Dokumente nur Level 2-6 Überschriften verwenden!
- Überschriften haben semantische Bedeutung welche von Browsern, Bots und Screenreadern interpretiert und verwendet wird.
  Überschriften sollten deshalb _niemals_ verwendet werden um Text einfach nur **fettgedruckt** oder in einer bestimmten Schriftgröße zu schreiben weil es ja "gut aussehen würde".
- Es sollte vermieden werden Überschriftenlevel zu überspringen. Siehe [hier](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/Heading_Elements#navigation) für eine Erklärung.



### Setext


Setext-Style Überschriften bestehen jeweils aus einer Zeile mit dem Überschriftstext gefolgt von einer Zeile mit `=`-Symbolen (für eine Level 1 Überschrift) oder  `-`-Symbolen (für eine Level 2 Überschrift).

```markdown
Eine Level 1 Überschrift
========================

Eine Level 2 Überschrift
------------------------
```

:::success
Eine Level 1 Überschrift
========================

Eine Level 2 Überschrift
------------------------
:::


### ATX

ATX-Style Überschriften bestehen jeweils aus einer Zeile mit ein bis sechs `#`-Symbolen gefolgt von mindestens einem Leerzeichen, dem jeweiligen Überschriftstext und einer optionalen Menge an weiteren `#`-Symbolen.
Die Anzahl der `#`-Symbole am Anfang der Zeile gibt das Level an.

```markdown
# Eine Level 1 Überschrift
## Eine Level 2 Überschrift
### Eine Level 3 Überschrift ###
#### Eine Level 4 Überschrift
##### Eine Level 5 Überschrift
###### Eine Level 6 Überschrift
```

:::success
# Eine Level 1 Überschrift
## Eine Level 2 Überschrift
### Eine Level 3 Überschrift ###
#### Eine Level 4 Überschrift
##### Eine Level 5 Überschrift
###### Eine Level 6 Überschrift
:::

### Identifikator, Attribute und Klassen

Am Ende der Zeile mit dem Überschriftentext kann man auch optionale Metadaten hinzugefügen.

Dafür schreibt man leerzeichengetrennt in geschweiften Klammern die folgenden Dinge:
- den Identifikator: `#Identifikator` (maximal einmal)
- die Klassen: `.eine-klasse .eine-andere-klasse .noch-eine-klasse`
	- Die Klasse `.unnumbered` makiert eine Überschrift als "soll nicht nummeriert werden". Als Alias reicht auch ein `-`.
	- Die Klasse `.unlisted` makiert eine Überschrfit als "soll im Inhaltsverzeichnis nicht eingetragen werden".

In den meisten Fällen wird maximal der Identifikator benötigt.
Der Identifaktor kann zum verlinken des entsprechenden Abschnittes verwendet werden.

```markdown
#### Eine Überschrift {#bspueberschrift}
#### Eine andere Überschrift {#anderebspueberschrift .mit-klassen .foobar}
#### Nich Nummeriert und nicht im Inhaltsverzeichnis {- .unlisted}
```

:::success
#### Eine Überschrift {#bspueberschrift}
#### Eine andere Überschrift {#anderebspueberschrift .mit-klassen .foobar}
#### Nich Nummeriert und nicht im Inhaltsverzeichnis {- .unlisted}
:::

:::info
Falls kein Identifikator für eine Überschrift gesetzt wurde, wird automatisch einer aus dem Überschriftentext generiert.

TODO
:::

:::danger
TODO continue https://pandoc.org/MANUAL.html#extension-header_attributes
:::

## Inlinemarkup
